Functions
- generate_
completions - Generates a standalone completion script for the given shell.
- get_
completion_ script_ only - Returns only the completion script (for –completions flag)
- get_
completions_ script - Returns the tab completion script for the given shell. This provides dynamic completion of directory names from the tries_path.
- get_
shell_ content - Returns the shell integration script content for the given shell type. This is used by –setup-stdout to print the content to stdout.
- get_
shell_ integration_ path - is_
shell_ integration_ configured - setup_
shell - Sets up shell integration for the given shell.