get_completions_script

Function get_completions_script 

pub fn get_completions_script(shell: &Shell) -> String
Returns the tab completion script for the given shell. This provides dynamic completion of directory names from the tries_path.