Module utils

Module utils 

Enums

SelectionResult

Functions

expand_path
extract_prefix_date
extract_repo_name
first_line
generate_prefix_date
get_folder_size_mb
get_free_disk_space_mb
is_git_url
is_git_worktree
Checks if a path is a git worktree (not the main working tree) A worktree has a .git file (not directory) that points to the main repo
is_git_worktree_locked
is_inside_git_repo
Checks if current directory is inside a git repository
matching_folders
remove_git_worktree