pub enum SelectionResult {
Folder(String),
New(String),
None,
}Variants
Folder(String)
A explicit folder that is guaranteed to exist already
New(String)
No existing match, a new folder should be created
None
Nothing was selected in the UI, quit