Module shell

Module shell 

Functions

generate_completions
Generates a standalone completion script for the given shell.
get_completion_script_only
Returns only the completion script (for –completions flag)
get_completions_script
Returns the tab completion script for the given shell. This provides dynamic completion of directory names from the tries_path.
get_shell_content
Returns the shell integration script content for the given shell type. This is used by –setup-stdout to print the content to stdout.
get_shell_integration_path
is_shell_integration_configured
setup_shell
Sets up shell integration for the given shell.