Enums
Functions
- expand_
path - extract_
prefix_ date - extract_
repo_ name - first_
line - generate_
prefix_ date - get_
folder_ size_ mb - get_
free_ disk_ space_ mb - is_
git_ url - is_
git_ worktree - Checks if a path is a git worktree (not the main working tree) A worktree has a .git file (not directory) that points to the main repo
- is_
git_ worktree_ locked - is_
inside_ git_ repo - Checks if current directory is inside a git repository
- matching_
folders - remove_
git_ worktree